# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class ThermalCamerasApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_thermal_camera(self, **kwargs):  # noqa: E501
        """Create ThermalCamera object with associated ThermalCameraSettings  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_thermal_camera(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ThermalCameraCreateRequest body: ThermalCamera and ThermalCameraSettings properties.
        :return: ThermalCameraResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_thermal_camera_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_thermal_camera_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_thermal_camera_with_http_info(self, **kwargs):  # noqa: E501
        """Create ThermalCamera object with associated ThermalCameraSettings  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_thermal_camera_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ThermalCameraCreateRequest body: ThermalCamera and ThermalCameraSettings properties.
        :return: ThermalCameraResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_thermal_camera" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ThermalCameraResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_thermal_camera_region(self, **kwargs):  # noqa: E501
        """Creates a Thermal Camera Region  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_thermal_camera_region(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ThermalCameraRegionCreateRequest body:
        :return: ThermalCameraRegionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_thermal_camera_region_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_thermal_camera_region_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_thermal_camera_region_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a Thermal Camera Region  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_thermal_camera_region_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ThermalCameraRegionCreateRequest body:
        :return: ThermalCameraRegionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_thermal_camera_region" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/regions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ThermalCameraRegionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_thermal_camera(self, thermal_camera_serial_number, **kwargs):  # noqa: E501
        """Deletes a ThermalCamera object and it's associated objects:  Regions, Images, Settings  # noqa: E501

        Deletion of a ThermalCamera is location admin only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_thermal_camera(thermal_camera_serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: The serial number of the ThermalCamera to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_thermal_camera_with_http_info(thermal_camera_serial_number, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_thermal_camera_with_http_info(thermal_camera_serial_number, **kwargs)  # noqa: E501
            return data

    def delete_thermal_camera_with_http_info(self, thermal_camera_serial_number, **kwargs):  # noqa: E501
        """Deletes a ThermalCamera object and it's associated objects:  Regions, Images, Settings  # noqa: E501

        Deletion of a ThermalCamera is location admin only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_thermal_camera_with_http_info(thermal_camera_serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: The serial number of the ThermalCamera to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['thermal_camera_serial_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_thermal_camera" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'thermal_camera_serial_number' is set
        if ('thermal_camera_serial_number' not in params or
                params['thermal_camera_serial_number'] is None):
            raise ValueError("Missing the required parameter `thermal_camera_serial_number` when calling `delete_thermal_camera`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'thermal_camera_serial_number' in params:
            path_params['thermalCameraSerialNumber'] = params['thermal_camera_serial_number']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/{thermalCameraSerialNumber}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_thermal_camera_region(self, region_id, **kwargs):  # noqa: E501
        """Deletes a Thermal Camera Region  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_thermal_camera_region(region_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str region_id: The id of the region to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_thermal_camera_region_with_http_info(region_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_thermal_camera_region_with_http_info(region_id, **kwargs)  # noqa: E501
            return data

    def delete_thermal_camera_region_with_http_info(self, region_id, **kwargs):  # noqa: E501
        """Deletes a Thermal Camera Region  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_thermal_camera_region_with_http_info(region_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str region_id: The id of the region to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['region_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_thermal_camera_region" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'region_id' is set
        if ('region_id' not in params or
                params['region_id'] is None):
            raise ValueError("Missing the required parameter `region_id` when calling `delete_thermal_camera_region`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'region_id' in params:
            path_params['regionId'] = params['region_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/regions/{regionId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_image(self, thermal_camera_serial_number, timestamp, **kwargs):  # noqa: E501
        """Gets a single thermal camera image  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_image(thermal_camera_serial_number, timestamp, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: The serial number of the camera (required)
        :param int timestamp: The unix timestamp of the image in ms (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_image_with_http_info(thermal_camera_serial_number, timestamp, **kwargs)  # noqa: E501
        else:
            (data) = self.get_image_with_http_info(thermal_camera_serial_number, timestamp, **kwargs)  # noqa: E501
            return data

    def get_image_with_http_info(self, thermal_camera_serial_number, timestamp, **kwargs):  # noqa: E501
        """Gets a single thermal camera image  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_image_with_http_info(thermal_camera_serial_number, timestamp, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: The serial number of the camera (required)
        :param int timestamp: The unix timestamp of the image in ms (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['thermal_camera_serial_number', 'timestamp']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'thermal_camera_serial_number' is set
        if ('thermal_camera_serial_number' not in params or
                params['thermal_camera_serial_number'] is None):
            raise ValueError("Missing the required parameter `thermal_camera_serial_number` when calling `get_image`")  # noqa: E501
        # verify the required parameter 'timestamp' is set
        if ('timestamp' not in params or
                params['timestamp'] is None):
            raise ValueError("Missing the required parameter `timestamp` when calling `get_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'thermal_camera_serial_number' in params:
            path_params['thermalCameraSerialNumber'] = params['thermal_camera_serial_number']  # noqa: E501
        if 'timestamp' in params:
            path_params['timestamp'] = params['timestamp']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/{thermalCameraSerialNumber}/images/{timestamp}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_latest_image(self, thermal_camera_serial_number, **kwargs):  # noqa: E501
        """Gets the latest ThermalCameraImage for a ThermalCamera  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_latest_image(thermal_camera_serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: The serial number of the camera (required)
        :return: ThermalCameraImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_latest_image_with_http_info(thermal_camera_serial_number, **kwargs)  # noqa: E501
        else:
            (data) = self.get_latest_image_with_http_info(thermal_camera_serial_number, **kwargs)  # noqa: E501
            return data

    def get_latest_image_with_http_info(self, thermal_camera_serial_number, **kwargs):  # noqa: E501
        """Gets the latest ThermalCameraImage for a ThermalCamera  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_latest_image_with_http_info(thermal_camera_serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: The serial number of the camera (required)
        :return: ThermalCameraImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['thermal_camera_serial_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_latest_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'thermal_camera_serial_number' is set
        if ('thermal_camera_serial_number' not in params or
                params['thermal_camera_serial_number'] is None):
            raise ValueError("Missing the required parameter `thermal_camera_serial_number` when calling `get_latest_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'thermal_camera_serial_number' in params:
            path_params['thermalCameraSerialNumber'] = params['thermal_camera_serial_number']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/{thermalCameraSerialNumber}/images/latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ThermalCameraImageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_thermal_camera(self, thermal_camera_serial_number, **kwargs):  # noqa: E501
        """Get a single ThermalCamera object  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thermal_camera(thermal_camera_serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: (required)
        :return: ThermalCameraResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_thermal_camera_with_http_info(thermal_camera_serial_number, **kwargs)  # noqa: E501
        else:
            (data) = self.get_thermal_camera_with_http_info(thermal_camera_serial_number, **kwargs)  # noqa: E501
            return data

    def get_thermal_camera_with_http_info(self, thermal_camera_serial_number, **kwargs):  # noqa: E501
        """Get a single ThermalCamera object  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thermal_camera_with_http_info(thermal_camera_serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: (required)
        :return: ThermalCameraResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['thermal_camera_serial_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_thermal_camera" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'thermal_camera_serial_number' is set
        if ('thermal_camera_serial_number' not in params or
                params['thermal_camera_serial_number'] is None):
            raise ValueError("Missing the required parameter `thermal_camera_serial_number` when calling `get_thermal_camera`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'thermal_camera_serial_number' in params:
            path_params['thermalCameraSerialNumber'] = params['thermal_camera_serial_number']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/{thermalCameraSerialNumber}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ThermalCameraResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_thermal_camera_region(self, region_id, **kwargs):  # noqa: E501
        """Gets a single Thermal Camera Region  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thermal_camera_region(region_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str region_id: The id of the region to get (required)
        :return: ThermalCameraRegionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_thermal_camera_region_with_http_info(region_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_thermal_camera_region_with_http_info(region_id, **kwargs)  # noqa: E501
            return data

    def get_thermal_camera_region_with_http_info(self, region_id, **kwargs):  # noqa: E501
        """Gets a single Thermal Camera Region  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thermal_camera_region_with_http_info(region_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str region_id: The id of the region to get (required)
        :return: ThermalCameraRegionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['region_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_thermal_camera_region" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'region_id' is set
        if ('region_id' not in params or
                params['region_id'] is None):
            raise ValueError("Missing the required parameter `region_id` when calling `get_thermal_camera_region`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'region_id' in params:
            path_params['regionId'] = params['region_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/regions/{regionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ThermalCameraRegionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_thermal_camera_regions(self, **kwargs):  # noqa: E501
        """Gets Thermal Camera Regions  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thermal_camera_regions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `ThermalCameraSerialNumber` | Int64 | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `Created` | DateTime | | `Height` | Int32 | | `Name` | String | | `Updated` | DateTime | | `Width` | Int32 |
        :return: PagedResultsModelThermalCameraRegionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_thermal_camera_regions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_thermal_camera_regions_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_thermal_camera_regions_with_http_info(self, **kwargs):  # noqa: E501
        """Gets Thermal Camera Regions  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thermal_camera_regions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `ThermalCameraSerialNumber` | Int64 | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `Created` | DateTime | | `Height` | Int32 | | `Name` | String | | `Updated` | DateTime | | `Width` | Int32 |
        :return: PagedResultsModelThermalCameraRegionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_thermal_camera_regions" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/regions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelThermalCameraRegionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_thermal_cameras(self, **kwargs):  # noqa: E501
        """Get multiple ThermalCamera objects  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thermal_cameras(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Updated` | DateTime | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `Created` | DateTime | | `LocationName` | String | | `Updated` | DateTime |
        :return: PagedResultsModelThermalCameraResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_thermal_cameras_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_thermal_cameras_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_thermal_cameras_with_http_info(self, **kwargs):  # noqa: E501
        """Get multiple ThermalCamera objects  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_thermal_cameras_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Updated` | DateTime | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `Created` | DateTime | | `LocationName` | String | | `Updated` | DateTime |
        :return: PagedResultsModelThermalCameraResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_thermal_cameras" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelThermalCameraResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_thermal_camera(self, thermal_camera_serial_number, **kwargs):  # noqa: E501
        """Updates a single Thermal Camera/ settings  # noqa: E501

        Updating a ThermalCamera is location admin only.  Updating a ThermalCamera Location is System Admin/Sentry only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_thermal_camera(thermal_camera_serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: The id of the thermal camera to update (required)
        :param ThermalCameraUpdateRequest body: The update request for a given Thermal Camera
        :return: ThermalCameraResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_thermal_camera_with_http_info(thermal_camera_serial_number, **kwargs)  # noqa: E501
        else:
            (data) = self.update_thermal_camera_with_http_info(thermal_camera_serial_number, **kwargs)  # noqa: E501
            return data

    def update_thermal_camera_with_http_info(self, thermal_camera_serial_number, **kwargs):  # noqa: E501
        """Updates a single Thermal Camera/ settings  # noqa: E501

        Updating a ThermalCamera is location admin only.  Updating a ThermalCamera Location is System Admin/Sentry only.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_thermal_camera_with_http_info(thermal_camera_serial_number, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int thermal_camera_serial_number: The id of the thermal camera to update (required)
        :param ThermalCameraUpdateRequest body: The update request for a given Thermal Camera
        :return: ThermalCameraResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['thermal_camera_serial_number', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_thermal_camera" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'thermal_camera_serial_number' is set
        if ('thermal_camera_serial_number' not in params or
                params['thermal_camera_serial_number'] is None):
            raise ValueError("Missing the required parameter `thermal_camera_serial_number` when calling `update_thermal_camera`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'thermal_camera_serial_number' in params:
            path_params['thermalCameraSerialNumber'] = params['thermal_camera_serial_number']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/{thermalCameraSerialNumber}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ThermalCameraResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_thermal_camera_region(self, region_id, **kwargs):  # noqa: E501
        """Updates a single Thermal Camera Region  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_thermal_camera_region(region_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str region_id: The id of the region to update (required)
        :param ThermalCameraRegionUpdateRequest body: The update request for a given Thermal Camera Region
        :return: ThermalCameraRegionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_thermal_camera_region_with_http_info(region_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_thermal_camera_region_with_http_info(region_id, **kwargs)  # noqa: E501
            return data

    def update_thermal_camera_region_with_http_info(self, region_id, **kwargs):  # noqa: E501
        """Updates a single Thermal Camera Region  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_thermal_camera_region_with_http_info(region_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str region_id: The id of the region to update (required)
        :param ThermalCameraRegionUpdateRequest body: The update request for a given Thermal Camera Region
        :return: ThermalCameraRegionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['region_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_thermal_camera_region" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'region_id' is set
        if ('region_id' not in params or
                params['region_id'] is None):
            raise ValueError("Missing the required parameter `region_id` when calling `update_thermal_camera_region`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'region_id' in params:
            path_params['regionId'] = params['region_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ThermalCameras/regions/{regionId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ThermalCameraRegionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from smart_diagnostics_client.api.activity_events_api import ActivityEventsApi
from smart_diagnostics_client.api.alerts_api import AlertsApi
from smart_diagnostics_client.api.analytics_api import AnalyticsApi
from smart_diagnostics_client.api.assets_api import AssetsApi
from smart_diagnostics_client.api.base_stations_api import BaseStationsApi
from smart_diagnostics_client.api.bearings_api import BearingsApi
from smart_diagnostics_client.api.board_ticket_statuses_api import BoardTicketStatusesApi
from smart_diagnostics_client.api.board_tickets_api import BoardTicketsApi
from smart_diagnostics_client.api.bulletins_api import BulletinsApi
from smart_diagnostics_client.api.corporations_api import CorporationsApi
from smart_diagnostics_client.api.dashboards_api import DashboardsApi
from smart_diagnostics_client.api.documents_api import DocumentsApi
from smart_diagnostics_client.api.events_api import EventsApi
from smart_diagnostics_client.api.files_api import FilesApi
from smart_diagnostics_client.api.filters_api import FiltersApi
from smart_diagnostics_client.api.groups_api import GroupsApi
from smart_diagnostics_client.api.hardware_events_api import HardwareEventsApi
from smart_diagnostics_client.api.hardware_status_api import HardwareStatusApi
from smart_diagnostics_client.api.hubs_api import HubsApi
from smart_diagnostics_client.api.identity_providers_api import IdentityProvidersApi
from smart_diagnostics_client.api.indicator_groups_api import IndicatorGroupsApi
from smart_diagnostics_client.api.indicators_api import IndicatorsApi
from smart_diagnostics_client.api.installs_api import InstallsApi
from smart_diagnostics_client.api.locations_api import LocationsApi
from smart_diagnostics_client.api.markers_api import MarkersApi
from smart_diagnostics_client.api.monitoring_point_type_codes_api import MonitoringPointTypeCodesApi
from smart_diagnostics_client.api.monitoring_points_api import MonitoringPointsApi
from smart_diagnostics_client.api.nodes_api import NodesApi
from smart_diagnostics_client.api.pictures_api import PicturesApi
from smart_diagnostics_client.api.properties_api import PropertiesApi
from smart_diagnostics_client.api.receivers_api import ReceiversApi
from smart_diagnostics_client.api.repeaters_api import RepeatersApi
from smart_diagnostics_client.api.reports_api import ReportsApi
from smart_diagnostics_client.api.sensors_api import SensorsApi
from smart_diagnostics_client.api.sessions_api import SessionsApi
from smart_diagnostics_client.api.setup_tools_api import SetupToolsApi
from smart_diagnostics_client.api.sub_systems_api import SubSystemsApi
from smart_diagnostics_client.api.systems_api import SystemsApi
from smart_diagnostics_client.api.tags_api import TagsApi
from smart_diagnostics_client.api.thermal_cameras_api import ThermalCamerasApi
from smart_diagnostics_client.api.tokens_api import TokensApi
from smart_diagnostics_client.api.tree_items_api import TreeItemsApi
from smart_diagnostics_client.api.user_permission_api import UserPermissionApi
from smart_diagnostics_client.api.users_api import UsersApi
# import ApiClient
from smart_diagnostics_client.api_client import ApiClient
from smart_diagnostics_client.configuration import Configuration
# import models into sdk package
from smart_diagnostics_client.models.acknowledged_alerts_response import AcknowledgedAlertsResponse
from smart_diagnostics_client.models.activity_event_assignment_child import ActivityEventAssignmentChild
from smart_diagnostics_client.models.activity_event_assignment_type import ActivityEventAssignmentType
from smart_diagnostics_client.models.activity_event_bind_child import ActivityEventBindChild
from smart_diagnostics_client.models.activity_event_bind_request import ActivityEventBindRequest
from smart_diagnostics_client.models.activity_event_bind_type import ActivityEventBindType
from smart_diagnostics_client.models.activity_event_category_child import ActivityEventCategoryChild
from smart_diagnostics_client.models.activity_event_category_flag import ActivityEventCategoryFlag
from smart_diagnostics_client.models.activity_event_category_owner_child import ActivityEventCategoryOwnerChild
from smart_diagnostics_client.models.activity_event_category_relationship_create_request import ActivityEventCategoryRelationshipCreateRequest
from smart_diagnostics_client.models.activity_event_category_relationship_response import ActivityEventCategoryRelationshipResponse
from smart_diagnostics_client.models.activity_event_category_response import ActivityEventCategoryResponse
from smart_diagnostics_client.models.activity_event_child import ActivityEventChild
from smart_diagnostics_client.models.activity_event_create_request import ActivityEventCreateRequest
from smart_diagnostics_client.models.activity_event_detail_response import ActivityEventDetailResponse
from smart_diagnostics_client.models.activity_event_document_request import ActivityEventDocumentRequest
from smart_diagnostics_client.models.activity_event_field_child import ActivityEventFieldChild
from smart_diagnostics_client.models.activity_event_field_entry_child import ActivityEventFieldEntryChild
from smart_diagnostics_client.models.activity_event_field_entry_request import ActivityEventFieldEntryRequest
from smart_diagnostics_client.models.activity_event_field_response import ActivityEventFieldResponse
from smart_diagnostics_client.models.activity_event_field_type import ActivityEventFieldType
from smart_diagnostics_client.models.activity_event_field_value_request import ActivityEventFieldValueRequest
from smart_diagnostics_client.models.activity_event_field_value_response import ActivityEventFieldValueResponse
from smart_diagnostics_client.models.activity_event_hierarchy_group_request import ActivityEventHierarchyGroupRequest
from smart_diagnostics_client.models.activity_event_hierarchy_group_response import ActivityEventHierarchyGroupResponse
from smart_diagnostics_client.models.activity_event_indicator_child import ActivityEventIndicatorChild
from smart_diagnostics_client.models.activity_event_owner_type import ActivityEventOwnerType
from smart_diagnostics_client.models.activity_event_relationship_child import ActivityEventRelationshipChild
from smart_diagnostics_client.models.activity_event_relationship_create_request import ActivityEventRelationshipCreateRequest
from smart_diagnostics_client.models.activity_event_relationship_response import ActivityEventRelationshipResponse
from smart_diagnostics_client.models.activity_event_relationship_type import ActivityEventRelationshipType
from smart_diagnostics_client.models.activity_event_response import ActivityEventResponse
from smart_diagnostics_client.models.activity_event_subcategory_child import ActivityEventSubcategoryChild
from smart_diagnostics_client.models.activity_event_subcategory_entry_request import ActivityEventSubcategoryEntryRequest
from smart_diagnostics_client.models.activity_event_subcategory_response import ActivityEventSubcategoryResponse
from smart_diagnostics_client.models.activity_event_update_request import ActivityEventUpdateRequest
from smart_diagnostics_client.models.alarm_definition_child import AlarmDefinitionChild
from smart_diagnostics_client.models.alert_acknowledgement_request import AlertAcknowledgementRequest
from smart_diagnostics_client.models.analytics_log_response import AnalyticsLogResponse
from smart_diagnostics_client.models.analytics_model_child import AnalyticsModelChild
from smart_diagnostics_client.models.analytics_model_create_request import AnalyticsModelCreateRequest
from smart_diagnostics_client.models.analytics_model_error_type_codes import AnalyticsModelErrorTypeCodes
from smart_diagnostics_client.models.analytics_model_indicator_child import AnalyticsModelIndicatorChild
from smart_diagnostics_client.models.analytics_model_response import AnalyticsModelResponse
from smart_diagnostics_client.models.analytics_model_status_update_request import AnalyticsModelStatusUpdateRequest
from smart_diagnostics_client.models.analytics_model_trigger_type import AnalyticsModelTriggerType
from smart_diagnostics_client.models.analytics_model_update_request import AnalyticsModelUpdateRequest
from smart_diagnostics_client.models.application_role_code import ApplicationRoleCode
from smart_diagnostics_client.models.asset_category_child import AssetCategoryChild
from smart_diagnostics_client.models.asset_category_create_request import AssetCategoryCreateRequest
from smart_diagnostics_client.models.asset_category_marker_child import AssetCategoryMarkerChild
from smart_diagnostics_client.models.asset_category_parameter_child import AssetCategoryParameterChild
from smart_diagnostics_client.models.asset_category_parameter_response import AssetCategoryParameterResponse
from smart_diagnostics_client.models.asset_category_parameter_type import AssetCategoryParameterType
from smart_diagnostics_client.models.asset_category_parameter_update_request import AssetCategoryParameterUpdateRequest
from smart_diagnostics_client.models.asset_category_parent_child import AssetCategoryParentChild
from smart_diagnostics_client.models.asset_category_response import AssetCategoryResponse
from smart_diagnostics_client.models.asset_category_type_response import AssetCategoryTypeResponse
from smart_diagnostics_client.models.asset_category_update_request import AssetCategoryUpdateRequest
from smart_diagnostics_client.models.asset_category_with_size_child import AssetCategoryWithSizeChild
from smart_diagnostics_client.models.asset_classification_assignment_response import AssetClassificationAssignmentResponse
from smart_diagnostics_client.models.asset_classification_assignment_update_request import AssetClassificationAssignmentUpdateRequest
from smart_diagnostics_client.models.asset_classification_category_child import AssetClassificationCategoryChild
from smart_diagnostics_client.models.asset_classification_parameter_value_child import AssetClassificationParameterValueChild
from smart_diagnostics_client.models.asset_classification_type_create_request import AssetClassificationTypeCreateRequest
from smart_diagnostics_client.models.asset_classification_type_update_request import AssetClassificationTypeUpdateRequest
from smart_diagnostics_client.models.asset_create_request import AssetCreateRequest
from smart_diagnostics_client.models.asset_criticality_child import AssetCriticalityChild
from smart_diagnostics_client.models.asset_drum_roll_child import AssetDrumRollChild
from smart_diagnostics_client.models.asset_economics_child import AssetEconomicsChild
from smart_diagnostics_client.models.asset_parameter_category_child import AssetParameterCategoryChild
from smart_diagnostics_client.models.asset_response import AssetResponse
from smart_diagnostics_client.models.asset_running_speed_child import AssetRunningSpeedChild
from smart_diagnostics_client.models.asset_running_speed_type import AssetRunningSpeedType
from smart_diagnostics_client.models.asset_size_child import AssetSizeChild
from smart_diagnostics_client.models.asset_type_child import AssetTypeChild
from smart_diagnostics_client.models.asset_type_response import AssetTypeResponse
from smart_diagnostics_client.models.asset_update_request import AssetUpdateRequest
from smart_diagnostics_client.models.assets_status_count_child import AssetsStatusCountChild
from smart_diagnostics_client.models.assets_status_percentage_child import AssetsStatusPercentageChild
from smart_diagnostics_client.models.attachment_model_v3 import AttachmentModelV3
from smart_diagnostics_client.models.band_definition_child import BandDefinitionChild
from smart_diagnostics_client.models.base_station_child import BaseStationChild
from smart_diagnostics_client.models.base_station_create_request import BaseStationCreateRequest
from smart_diagnostics_client.models.base_station_node_child import BaseStationNodeChild
from smart_diagnostics_client.models.base_station_receiver_child import BaseStationReceiverChild
from smart_diagnostics_client.models.base_station_response import BaseStationResponse
from smart_diagnostics_client.models.base_station_update_request import BaseStationUpdateRequest
from smart_diagnostics_client.models.baseline_indicator_child import BaselineIndicatorChild
from smart_diagnostics_client.models.baseline_with_significant_digits_child import BaselineWithSignificantDigitsChild
from smart_diagnostics_client.models.bearing_child import BearingChild
from smart_diagnostics_client.models.bearing_response import BearingResponse
from smart_diagnostics_client.models.board_child import BoardChild
from smart_diagnostics_client.models.board_ticket_status_create_request import BoardTicketStatusCreateRequest
from smart_diagnostics_client.models.board_ticket_status_update_request import BoardTicketStatusUpdateRequest
from smart_diagnostics_client.models.bulletin_response import BulletinResponse
from smart_diagnostics_client.models.bulletin_update_request import BulletinUpdateRequest
from smart_diagnostics_client.models.case_content_type_for_api import CaseContentTypeForApi
from smart_diagnostics_client.models.content_type import ContentType
from smart_diagnostics_client.models.content_type_hierarchy_level_enum import ContentTypeHierarchyLevelEnum
from smart_diagnostics_client.models.corporation_child import CorporationChild
from smart_diagnostics_client.models.corporation_create_request import CorporationCreateRequest
from smart_diagnostics_client.models.corporation_industry_child import CorporationIndustryChild
from smart_diagnostics_client.models.corporation_permission_create_request import CorporationPermissionCreateRequest
from smart_diagnostics_client.models.corporation_permission_update_request import CorporationPermissionUpdateRequest
from smart_diagnostics_client.models.corporation_response import CorporationResponse
from smart_diagnostics_client.models.corporation_update_request import CorporationUpdateRequest
from smart_diagnostics_client.models.corporation_user_role import CorporationUserRole
from smart_diagnostics_client.models.current_software_release_child import CurrentSoftwareReleaseChild
from smart_diagnostics_client.models.current_user_response import CurrentUserResponse
from smart_diagnostics_client.models.current_user_update_request import CurrentUserUpdateRequest
from smart_diagnostics_client.models.custom_marker_child import CustomMarkerChild
from smart_diagnostics_client.models.dashboard_create_request import DashboardCreateRequest
from smart_diagnostics_client.models.dashboard_permissions_update_request import DashboardPermissionsUpdateRequest
from smart_diagnostics_client.models.dashboard_response import DashboardResponse
from smart_diagnostics_client.models.dashboard_template_response import DashboardTemplateResponse
from smart_diagnostics_client.models.dashboard_type_child import DashboardTypeChild
from smart_diagnostics_client.models.dashboard_update_request import DashboardUpdateRequest
from smart_diagnostics_client.models.dashboard_widget_child import DashboardWidgetChild
from smart_diagnostics_client.models.dashboard_widget_request_child import DashboardWidgetRequestChild
from smart_diagnostics_client.models.descendant_child import DescendantChild
from smart_diagnostics_client.models.document_child import DocumentChild
from smart_diagnostics_client.models.enum_option_child_user_role_codes import EnumOptionChildUserRoleCodes
from smart_diagnostics_client.models.event_model_v3 import EventModelV3
from smart_diagnostics_client.models.external_notification_child import ExternalNotificationChild
from smart_diagnostics_client.models.external_notification_type import ExternalNotificationType
from smart_diagnostics_client.models.files_error import FilesError
from smart_diagnostics_client.models.files_update_request import FilesUpdateRequest
from smart_diagnostics_client.models.frequency_domain_setting_child import FrequencyDomainSettingChild
from smart_diagnostics_client.models.general_detail_error import GeneralDetailError
from smart_diagnostics_client.models.group_alerts_response import GroupAlertsResponse
from smart_diagnostics_client.models.group_analytics_model_add_request import GroupAnalyticsModelAddRequest
from smart_diagnostics_client.models.group_analytics_model_response import GroupAnalyticsModelResponse
from smart_diagnostics_client.models.group_analytics_model_update_request import GroupAnalyticsModelUpdateRequest
from smart_diagnostics_client.models.group_child import GroupChild
from smart_diagnostics_client.models.group_move_request import GroupMoveRequest
from smart_diagnostics_client.models.group_status_response import GroupStatusResponse
from smart_diagnostics_client.models.group_type_codes import GroupTypeCodes
from smart_diagnostics_client.models.group_type_codes_for_api import GroupTypeCodesForApi
from smart_diagnostics_client.models.hardware_event_model_v3 import HardwareEventModelV3
from smart_diagnostics_client.models.hardware_model_v3 import HardwareModelV3
from smart_diagnostics_client.models.hardware_revision_child import HardwareRevisionChild
from smart_diagnostics_client.models.hardware_status_child import HardwareStatusChild
from smart_diagnostics_client.models.hardware_status_response import HardwareStatusResponse
from smart_diagnostics_client.models.heatmap_aggregate_level import HeatmapAggregateLevel
from smart_diagnostics_client.models.heatmap_report_request import HeatmapReportRequest
from smart_diagnostics_client.models.hierarchy_child import HierarchyChild
from smart_diagnostics_client.models.hub_child import HubChild
from smart_diagnostics_client.models.hub_node_child import HubNodeChild
from smart_diagnostics_client.models.hub_overview_response import HubOverviewResponse
from smart_diagnostics_client.models.hub_port_child import HubPortChild
from smart_diagnostics_client.models.hub_power_type import HubPowerType
from smart_diagnostics_client.models.hub_response import HubResponse
from smart_diagnostics_client.models.hub_type import HubType
from smart_diagnostics_client.models.id_icon_body import IdIconBody
from smart_diagnostics_client.models.id_image_body import IdImageBody
from smart_diagnostics_client.models.identity_provider_create_request import IdentityProviderCreateRequest
from smart_diagnostics_client.models.identity_provider_response import IdentityProviderResponse
from smart_diagnostics_client.models.identity_provider_update_request import IdentityProviderUpdateRequest
from smart_diagnostics_client.models.indicator_alarm_state_response import IndicatorAlarmStateResponse
from smart_diagnostics_client.models.indicator_baseline_response import IndicatorBaselineResponse
from smart_diagnostics_client.models.indicator_filter_create_request import IndicatorFilterCreateRequest
from smart_diagnostics_client.models.indicator_filter_response import IndicatorFilterResponse
from smart_diagnostics_client.models.indicator_filter_update_request import IndicatorFilterUpdateRequest
from smart_diagnostics_client.models.indicator_group_create_request import IndicatorGroupCreateRequest
from smart_diagnostics_client.models.indicator_group_response import IndicatorGroupResponse
from smart_diagnostics_client.models.indicator_group_update_request import IndicatorGroupUpdateRequest
from smart_diagnostics_client.models.indicator_measure_of_code_child import IndicatorMeasureOfCodeChild
from smart_diagnostics_client.models.indicator_options_response import IndicatorOptionsResponse
from smart_diagnostics_client.models.indicator_response import IndicatorResponse
from smart_diagnostics_client.models.indicator_statistics_hierarchy_child import IndicatorStatisticsHierarchyChild
from smart_diagnostics_client.models.indicator_statistics_response import IndicatorStatisticsResponse
from smart_diagnostics_client.models.indicator_type_category_child import IndicatorTypeCategoryChild
from smart_diagnostics_client.models.indicator_types_response import IndicatorTypesResponse
from smart_diagnostics_client.models.install_add_user_response import InstallAddUserResponse
from smart_diagnostics_client.models.install_modify_users_request import InstallModifyUsersRequest
from smart_diagnostics_client.models.install_node_response import InstallNodeResponse
from smart_diagnostics_client.models.install_node_status_child import InstallNodeStatusChild
from smart_diagnostics_client.models.install_node_update_request import InstallNodeUpdateRequest
from smart_diagnostics_client.models.install_nodes_status_child import InstallNodesStatusChild
from smart_diagnostics_client.models.install_response import InstallResponse
from smart_diagnostics_client.models.install_update_request import InstallUpdateRequest
from smart_diagnostics_client.models.job_response import JobResponse
from smart_diagnostics_client.models.job_status import JobStatus
from smart_diagnostics_client.models.job_type import JobType
from smart_diagnostics_client.models.job_upload_error_response import JobUploadErrorResponse
from smart_diagnostics_client.models.json_patch_document import JsonPatchDocument
from smart_diagnostics_client.models.layout_child import LayoutChild
from smart_diagnostics_client.models.location_child import LocationChild
from smart_diagnostics_client.models.location_create_request import LocationCreateRequest
from smart_diagnostics_client.models.location_permission_create_request import LocationPermissionCreateRequest
from smart_diagnostics_client.models.location_permission_update_request import LocationPermissionUpdateRequest
from smart_diagnostics_client.models.location_permissions_response import LocationPermissionsResponse
from smart_diagnostics_client.models.location_permissions_update_request import LocationPermissionsUpdateRequest
from smart_diagnostics_client.models.location_response import LocationResponse
from smart_diagnostics_client.models.location_settings_child import LocationSettingsChild
from smart_diagnostics_client.models.location_update_request import LocationUpdateRequest
from smart_diagnostics_client.models.location_user_role import LocationUserRole
from smart_diagnostics_client.models.long_burst_request_child import LongBurstRequestChild
from smart_diagnostics_client.models.long_burst_request_state import LongBurstRequestState
from smart_diagnostics_client.models.marker_child import MarkerChild
from smart_diagnostics_client.models.marker_create_request import MarkerCreateRequest
from smart_diagnostics_client.models.marker_response import MarkerResponse
from smart_diagnostics_client.models.marker_type import MarkerType
from smart_diagnostics_client.models.marker_update_request import MarkerUpdateRequest
from smart_diagnostics_client.models.metric_classification_source_enum import MetricClassificationSourceEnum
from smart_diagnostics_client.models.metric_type_code_category import MetricTypeCodeCategory
from smart_diagnostics_client.models.metric_type_codes import MetricTypeCodes
from smart_diagnostics_client.models.model_id_source_body import ModelIdSourceBody
from smart_diagnostics_client.models.monitoring_point_assignment_response import MonitoringPointAssignmentResponse
from smart_diagnostics_client.models.monitoring_point_child import MonitoringPointChild
from smart_diagnostics_client.models.monitoring_point_create_request import MonitoringPointCreateRequest
from smart_diagnostics_client.models.monitoring_point_node_child import MonitoringPointNodeChild
from smart_diagnostics_client.models.monitoring_point_overview_node_child import MonitoringPointOverviewNodeChild
from smart_diagnostics_client.models.monitoring_point_overview_response import MonitoringPointOverviewResponse
from smart_diagnostics_client.models.monitoring_point_response import MonitoringPointResponse
from smart_diagnostics_client.models.monitoring_point_type_code_model import MonitoringPointTypeCodeModel
from smart_diagnostics_client.models.monitoring_point_type_codes import MonitoringPointTypeCodes
from smart_diagnostics_client.models.monitoring_point_type_codes_for_api import MonitoringPointTypeCodesForApi
from smart_diagnostics_client.models.monitoring_point_update_request import MonitoringPointUpdateRequest
from smart_diagnostics_client.models.move_files_request import MoveFilesRequest
from smart_diagnostics_client.models.move_files_response import MoveFilesResponse
from smart_diagnostics_client.models.node_child import NodeChild
from smart_diagnostics_client.models.node_response import NodeResponse
from smart_diagnostics_client.models.node_setting_child import NodeSettingChild
from smart_diagnostics_client.models.node_setting_overview import NodeSettingOverview
from smart_diagnostics_client.models.node_setting_values import NodeSettingValues
from smart_diagnostics_client.models.node_status_child import NodeStatusChild
from smart_diagnostics_client.models.node_type_codes import NodeTypeCodes
from smart_diagnostics_client.models.operation import Operation
from smart_diagnostics_client.models.option_child import OptionChild
from smart_diagnostics_client.models.option_model import OptionModel
from smart_diagnostics_client.models.overview_hierarchy_child import OverviewHierarchyChild
from smart_diagnostics_client.models.paged_results_model_activity_event_category_response import PagedResultsModelActivityEventCategoryResponse
from smart_diagnostics_client.models.paged_results_model_activity_event_hierarchy_group_response import PagedResultsModelActivityEventHierarchyGroupResponse
from smart_diagnostics_client.models.paged_results_model_activity_event_response import PagedResultsModelActivityEventResponse
from smart_diagnostics_client.models.paged_results_model_analytics_log_response import PagedResultsModelAnalyticsLogResponse
from smart_diagnostics_client.models.paged_results_model_analytics_model_response import PagedResultsModelAnalyticsModelResponse
from smart_diagnostics_client.models.paged_results_model_asset_category_response import PagedResultsModelAssetCategoryResponse
from smart_diagnostics_client.models.paged_results_model_asset_category_type_response import PagedResultsModelAssetCategoryTypeResponse
from smart_diagnostics_client.models.paged_results_model_asset_response import PagedResultsModelAssetResponse
from smart_diagnostics_client.models.paged_results_model_asset_type_response import PagedResultsModelAssetTypeResponse
from smart_diagnostics_client.models.paged_results_model_base_station_response import PagedResultsModelBaseStationResponse
from smart_diagnostics_client.models.paged_results_model_bearing_response import PagedResultsModelBearingResponse
from smart_diagnostics_client.models.paged_results_model_bulletin_response import PagedResultsModelBulletinResponse
from smart_diagnostics_client.models.paged_results_model_corporation_response import PagedResultsModelCorporationResponse
from smart_diagnostics_client.models.paged_results_model_dashboard_response import PagedResultsModelDashboardResponse
from smart_diagnostics_client.models.paged_results_model_dashboard_template_response import PagedResultsModelDashboardTemplateResponse
from smart_diagnostics_client.models.paged_results_model_group_alerts_response import PagedResultsModelGroupAlertsResponse
from smart_diagnostics_client.models.paged_results_model_group_analytics_model_response import PagedResultsModelGroupAnalyticsModelResponse
from smart_diagnostics_client.models.paged_results_model_group_status_response import PagedResultsModelGroupStatusResponse
from smart_diagnostics_client.models.paged_results_model_hardware_event_model_v3 import PagedResultsModelHardwareEventModelV3
from smart_diagnostics_client.models.paged_results_model_hub_overview_response import PagedResultsModelHubOverviewResponse
from smart_diagnostics_client.models.paged_results_model_hub_response import PagedResultsModelHubResponse
from smart_diagnostics_client.models.paged_results_model_identity_provider_response import PagedResultsModelIdentityProviderResponse
from smart_diagnostics_client.models.paged_results_model_indicator_baseline_response import PagedResultsModelIndicatorBaselineResponse
from smart_diagnostics_client.models.paged_results_model_indicator_filter_response import PagedResultsModelIndicatorFilterResponse
from smart_diagnostics_client.models.paged_results_model_indicator_group_response import PagedResultsModelIndicatorGroupResponse
from smart_diagnostics_client.models.paged_results_model_indicator_response import PagedResultsModelIndicatorResponse
from smart_diagnostics_client.models.paged_results_model_indicator_statistics_response import PagedResultsModelIndicatorStatisticsResponse
from smart_diagnostics_client.models.paged_results_model_install_node_response import PagedResultsModelInstallNodeResponse
from smart_diagnostics_client.models.paged_results_model_install_response import PagedResultsModelInstallResponse
from smart_diagnostics_client.models.paged_results_model_location_response import PagedResultsModelLocationResponse
from smart_diagnostics_client.models.paged_results_model_monitoring_point_assignment_response import PagedResultsModelMonitoringPointAssignmentResponse
from smart_diagnostics_client.models.paged_results_model_monitoring_point_overview_response import PagedResultsModelMonitoringPointOverviewResponse
from smart_diagnostics_client.models.paged_results_model_monitoring_point_response import PagedResultsModelMonitoringPointResponse
from smart_diagnostics_client.models.paged_results_model_node_response import PagedResultsModelNodeResponse
from smart_diagnostics_client.models.paged_results_model_personal_access_token_response import PagedResultsModelPersonalAccessTokenResponse
from smart_diagnostics_client.models.paged_results_model_picture_file_metadata_response import PagedResultsModelPictureFileMetadataResponse
from smart_diagnostics_client.models.paged_results_model_pictures_model_v3 import PagedResultsModelPicturesModelV3
from smart_diagnostics_client.models.paged_results_model_property_response import PagedResultsModelPropertyResponse
from smart_diagnostics_client.models.paged_results_model_receiver_response import PagedResultsModelReceiverResponse
from smart_diagnostics_client.models.paged_results_model_repeater_response import PagedResultsModelRepeaterResponse
from smart_diagnostics_client.models.paged_results_model_sensor_role_response import PagedResultsModelSensorRoleResponse
from smart_diagnostics_client.models.paged_results_model_sub_system_response import PagedResultsModelSubSystemResponse
from smart_diagnostics_client.models.paged_results_model_system_assets_status_summary_response import PagedResultsModelSystemAssetsStatusSummaryResponse
from smart_diagnostics_client.models.paged_results_model_system_overview_response import PagedResultsModelSystemOverviewResponse
from smart_diagnostics_client.models.paged_results_model_system_response import PagedResultsModelSystemResponse
from smart_diagnostics_client.models.paged_results_model_tag_response import PagedResultsModelTagResponse
from smart_diagnostics_client.models.paged_results_model_thermal_camera_region_response import PagedResultsModelThermalCameraRegionResponse
from smart_diagnostics_client.models.paged_results_model_thermal_camera_response import PagedResultsModelThermalCameraResponse
from smart_diagnostics_client.models.paged_results_model_ticket_response import PagedResultsModelTicketResponse
from smart_diagnostics_client.models.paged_results_model_tree_item_available_asset_class_response import PagedResultsModelTreeItemAvailableAssetClassResponse
from smart_diagnostics_client.models.paged_results_model_tree_item_response import PagedResultsModelTreeItemResponse
from smart_diagnostics_client.models.paged_results_model_user_response import PagedResultsModelUserResponse
from smart_diagnostics_client.models.parent_child import ParentChild
from smart_diagnostics_client.models.patch_request import PatchRequest
from smart_diagnostics_client.models.personal_access_token_create_request import PersonalAccessTokenCreateRequest
from smart_diagnostics_client.models.personal_access_token_create_response import PersonalAccessTokenCreateResponse
from smart_diagnostics_client.models.personal_access_token_response import PersonalAccessTokenResponse
from smart_diagnostics_client.models.personal_access_token_update_request import PersonalAccessTokenUpdateRequest
from smart_diagnostics_client.models.picture_file_metadata_response import PictureFileMetadataResponse
from smart_diagnostics_client.models.pictures_model_v3 import PicturesModelV3
from smart_diagnostics_client.models.power_bi_error import PowerBiError
from smart_diagnostics_client.models.power_bi_report_child import PowerBiReportChild
from smart_diagnostics_client.models.primary_corporation_child import PrimaryCorporationChild
from smart_diagnostics_client.models.problem_details import ProblemDetails
from smart_diagnostics_client.models.profile_child import ProfileChild
from smart_diagnostics_client.models.profile_options_response import ProfileOptionsResponse
from smart_diagnostics_client.models.property_child import PropertyChild
from smart_diagnostics_client.models.property_request_child import PropertyRequestChild
from smart_diagnostics_client.models.property_response import PropertyResponse
from smart_diagnostics_client.models.property_value_type import PropertyValueType
from smart_diagnostics_client.models.receiver_child import ReceiverChild
from smart_diagnostics_client.models.receiver_location_type_codes import ReceiverLocationTypeCodes
from smart_diagnostics_client.models.receiver_response import ReceiverResponse
from smart_diagnostics_client.models.receiver_type_codes import ReceiverTypeCodes
from smart_diagnostics_client.models.release_ring_child import ReleaseRingChild
from smart_diagnostics_client.models.repeater_child import RepeaterChild
from smart_diagnostics_client.models.repeater_node_child import RepeaterNodeChild
from smart_diagnostics_client.models.repeater_response import RepeaterResponse
from smart_diagnostics_client.models.roi_response import RoiResponse
from smart_diagnostics_client.models.sensor_role_response import SensorRoleResponse
from smart_diagnostics_client.models.sensor_role_type_codes import SensorRoleTypeCodes
from smart_diagnostics_client.models.session_create_request import SessionCreateRequest
from smart_diagnostics_client.models.session_indicator_type_child import SessionIndicatorTypeChild
from smart_diagnostics_client.models.session_measure_of_child import SessionMeasureOfChild
from smart_diagnostics_client.models.session_response import SessionResponse
from smart_diagnostics_client.models.session_selected_point_child import SessionSelectedPointChild
from smart_diagnostics_client.models.session_time_range_child import SessionTimeRangeChild
from smart_diagnostics_client.models.set_property_child import SetPropertyChild
from smart_diagnostics_client.models.setup_tools_job_type_body import SetupToolsJobTypeBody
from smart_diagnostics_client.models.smart_alarms_request import SmartAlarmsRequest
from smart_diagnostics_client.models.spectrum_chart_settings_create_request import SpectrumChartSettingsCreateRequest
from smart_diagnostics_client.models.spectrum_chart_settings_response import SpectrumChartSettingsResponse
from smart_diagnostics_client.models.statistics_report_request import StatisticsReportRequest
from smart_diagnostics_client.models.status_child import StatusChild
from smart_diagnostics_client.models.status_response import StatusResponse
from smart_diagnostics_client.models.sub_system_create_request import SubSystemCreateRequest
from smart_diagnostics_client.models.sub_system_response import SubSystemResponse
from smart_diagnostics_client.models.sub_system_update_request import SubSystemUpdateRequest
from smart_diagnostics_client.models.system_assets_status_summary_response import SystemAssetsStatusSummaryResponse
from smart_diagnostics_client.models.system_child import SystemChild
from smart_diagnostics_client.models.system_create_request import SystemCreateRequest
from smart_diagnostics_client.models.system_overview_response import SystemOverviewResponse
from smart_diagnostics_client.models.system_response import SystemResponse
from smart_diagnostics_client.models.system_update_request import SystemUpdateRequest
from smart_diagnostics_client.models.tag_categories import TagCategories
from smart_diagnostics_client.models.tag_child import TagChild
from smart_diagnostics_client.models.tag_create_request import TagCreateRequest
from smart_diagnostics_client.models.tag_response import TagResponse
from smart_diagnostics_client.models.tag_update_request import TagUpdateRequest
from smart_diagnostics_client.models.targeted_software_release_child import TargetedSoftwareReleaseChild
from smart_diagnostics_client.models.thermal_camera_create_request import ThermalCameraCreateRequest
from smart_diagnostics_client.models.thermal_camera_image_response import ThermalCameraImageResponse
from smart_diagnostics_client.models.thermal_camera_region_create_request import ThermalCameraRegionCreateRequest
from smart_diagnostics_client.models.thermal_camera_region_location_child import ThermalCameraRegionLocationChild
from smart_diagnostics_client.models.thermal_camera_region_response import ThermalCameraRegionResponse
from smart_diagnostics_client.models.thermal_camera_region_update_request import ThermalCameraRegionUpdateRequest
from smart_diagnostics_client.models.thermal_camera_response import ThermalCameraResponse
from smart_diagnostics_client.models.thermal_camera_settings_child import ThermalCameraSettingsChild
from smart_diagnostics_client.models.thermal_camera_settings_create_request import ThermalCameraSettingsCreateRequest
from smart_diagnostics_client.models.thermal_camera_settings_update_request import ThermalCameraSettingsUpdateRequest
from smart_diagnostics_client.models.thermal_camera_update_request import ThermalCameraUpdateRequest
from smart_diagnostics_client.models.ticket_create_request import TicketCreateRequest
from smart_diagnostics_client.models.ticket_response import TicketResponse
from smart_diagnostics_client.models.ticket_update_request import TicketUpdateRequest
from smart_diagnostics_client.models.time_range_model_v3 import TimeRangeModelV3
from smart_diagnostics_client.models.token_exchange_request import TokenExchangeRequest
from smart_diagnostics_client.models.token_exchange_response import TokenExchangeResponse
from smart_diagnostics_client.models.tree_item_available_asset_class_response import TreeItemAvailableAssetClassResponse
from smart_diagnostics_client.models.tree_item_child import TreeItemChild
from smart_diagnostics_client.models.tree_item_descendant_child import TreeItemDescendantChild
from smart_diagnostics_client.models.tree_item_response import TreeItemResponse
from smart_diagnostics_client.models.trigger_child import TriggerChild
from smart_diagnostics_client.models.update_bearings_for_group_request import UpdateBearingsForGroupRequest
from smart_diagnostics_client.models.user_child import UserChild
from smart_diagnostics_client.models.user_confirm_password_request import UserConfirmPasswordRequest
from smart_diagnostics_client.models.user_corporation_child import UserCorporationChild
from smart_diagnostics_client.models.user_create_request import UserCreateRequest
from smart_diagnostics_client.models.user_location_child import UserLocationChild
from smart_diagnostics_client.models.user_permissions_options_response import UserPermissionsOptionsResponse
from smart_diagnostics_client.models.user_phone_number_confirm_request import UserPhoneNumberConfirmRequest
from smart_diagnostics_client.models.user_profile_response import UserProfileResponse
from smart_diagnostics_client.models.user_profile_update_request import UserProfileUpdateRequest
from smart_diagnostics_client.models.user_request_corporation_child import UserRequestCorporationChild
from smart_diagnostics_client.models.user_request_location_child import UserRequestLocationChild
from smart_diagnostics_client.models.user_response import UserResponse
from smart_diagnostics_client.models.user_role_codes import UserRoleCodes
from smart_diagnostics_client.models.user_update_request import UserUpdateRequest
from smart_diagnostics_client.models.v30_bulletins_body import V30BulletinsBody
from smart_diagnostics_client.models.v30_files_body import V30FilesBody
from smart_diagnostics_client.models.validation_problem_details import ValidationProblemDetails
from smart_diagnostics_client.models.widget_child import WidgetChild
from smart_diagnostics_client.models.widget_code import WidgetCode
from smart_diagnostics_client.models.widget_template_child import WidgetTemplateChild
from smart_diagnostics_client.models.widget_template_filter_child import WidgetTemplateFilterChild
from smart_diagnostics_client.models.widget_time_range_values import WidgetTimeRangeValues
from smart_diagnostics_client.models.widget_type import WidgetType
from smart_diagnostics_client.models.widget_type_child import WidgetTypeChild



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.reports_api import ReportsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self):
        self.api = ReportsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_request_base_station_report(self):
        """Test case for request_base_station_report

        This will download a base station and repeater hardware report for the locations provided in the details model  # noqa: E501
        """
        pass

    def test_request_heatmap_report(self):
        """Test case for request_heatmap_report

        Enqueues a job to run and later email a heatmap report for the group provided using the options provided  # noqa: E501
        """
        pass

    def test_request_low_battery_report(self):
        """Test case for request_low_battery_report

        This will download a low battery report for the location provided in the details model  # noqa: E501
        """
        pass

    def test_request_statistics_report(self):
        """Test case for request_statistics_report

        Emails a statistics report for the group provided using the options provided  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.files_api import FilesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestFilesApi(unittest.TestCase):
    """FilesApi unit test stubs"""

    def setUp(self):
        self.api = FilesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_file(self):
        """Test case for create_file

        Creates a file  # noqa: E501
        """
        pass

    def test_delete_file(self):
        """Test case for delete_file

        Deletes a file  # noqa: E501
        """
        pass

    def test_get_corporation_files(self):
        """Test case for get_corporation_files

        Gets all files for a corporation  # noqa: E501
        """
        pass

    def test_get_file(self):
        """Test case for get_file

        Gets a file  # noqa: E501
        """
        pass

    def test_get_file_object(self):
        """Test case for get_file_object

        Gets a file object  # noqa: E501
        """
        pass

    def test_get_files(self):
        """Test case for get_files

        Get all the files  # noqa: E501
        """
        pass

    def test_get_location_files(self):
        """Test case for get_location_files

        Gets all files for a location  # noqa: E501
        """
        pass

    def test_move_files(self):
        """Test case for move_files

        Moves files to a folder  # noqa: E501
        """
        pass

    def test_update_file(self):
        """Test case for update_file

        Update a file  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TagResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'active': 'bool',
        'type': 'TagCategories',
        'is_global': 'bool',
        'created': 'datetime',
        'updated': 'datetime',
        'location': 'LocationChild'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'active': 'Active',
        'type': 'Type',
        'is_global': 'IsGlobal',
        'created': 'Created',
        'updated': 'Updated',
        'location': 'Location'
    }

    def __init__(self, id=None, name=None, active=None, type=None, is_global=None, created=None, updated=None, location=None):  # noqa: E501
        """TagResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._active = None
        self._type = None
        self._is_global = None
        self._created = None
        self._updated = None
        self._location = None
        self.discriminator = None
        self.id = id
        self.name = name
        self.active = active
        self.type = type
        if is_global is not None:
            self.is_global = is_global
        self.created = created
        self.updated = updated
        if location is not None:
            self.location = location

    @property
    def id(self):
        """Gets the id of this TagResponse.  # noqa: E501

        Id of the tag  # noqa: E501

        :return: The id of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TagResponse.

        Id of the tag  # noqa: E501

        :param id: The id of this TagResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this TagResponse.  # noqa: E501

        Name of the tag  # noqa: E501

        :return: The name of this TagResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TagResponse.

        Name of the tag  # noqa: E501

        :param name: The name of this TagResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def active(self):
        """Gets the active of this TagResponse.  # noqa: E501

        Indicates if a tag is active  # noqa: E501

        :return: The active of this TagResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this TagResponse.

        Indicates if a tag is active  # noqa: E501

        :param active: The active of this TagResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def type(self):
        """Gets the type of this TagResponse.  # noqa: E501


        :return: The type of this TagResponse.  # noqa: E501
        :rtype: TagCategories
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TagResponse.


        :param type: The type of this TagResponse.  # noqa: E501
        :type: TagCategories
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def is_global(self):
        """Gets the is_global of this TagResponse.  # noqa: E501

        Indicates if tag is global  # noqa: E501

        :return: The is_global of this TagResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_global

    @is_global.setter
    def is_global(self, is_global):
        """Sets the is_global of this TagResponse.

        Indicates if tag is global  # noqa: E501

        :param is_global: The is_global of this TagResponse.  # noqa: E501
        :type: bool
        """

        self._is_global = is_global

    @property
    def created(self):
        """Gets the created of this TagResponse.  # noqa: E501

        Date tag was created  # noqa: E501

        :return: The created of this TagResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this TagResponse.

        Date tag was created  # noqa: E501

        :param created: The created of this TagResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this TagResponse.  # noqa: E501

        Date tag was updated  # noqa: E501

        :return: The updated of this TagResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this TagResponse.

        Date tag was updated  # noqa: E501

        :param updated: The updated of this TagResponse.  # noqa: E501
        :type: datetime
        """
        if updated is None:
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    @property
    def location(self):
        """Gets the location of this TagResponse.  # noqa: E501


        :return: The location of this TagResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this TagResponse.


        :param location: The location of this TagResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TagResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PowerBiReportChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'power_bi_report_access_token': 'str',
        'power_bi_report_name': 'str',
        'power_bi_report_url': 'str',
        'power_bi_report_embed_url': 'str',
        'error': 'PowerBiError'
    }

    attribute_map = {
        'power_bi_report_access_token': 'PowerBiReportAccessToken',
        'power_bi_report_name': 'PowerBiReportName',
        'power_bi_report_url': 'PowerBiReportUrl',
        'power_bi_report_embed_url': 'PowerBiReportEmbedUrl',
        'error': 'Error'
    }

    def __init__(self, power_bi_report_access_token=None, power_bi_report_name=None, power_bi_report_url=None, power_bi_report_embed_url=None, error=None):  # noqa: E501
        """PowerBiReportChild - a model defined in Swagger"""  # noqa: E501
        self._power_bi_report_access_token = None
        self._power_bi_report_name = None
        self._power_bi_report_url = None
        self._power_bi_report_embed_url = None
        self._error = None
        self.discriminator = None
        if power_bi_report_access_token is not None:
            self.power_bi_report_access_token = power_bi_report_access_token
        if power_bi_report_name is not None:
            self.power_bi_report_name = power_bi_report_name
        if power_bi_report_url is not None:
            self.power_bi_report_url = power_bi_report_url
        if power_bi_report_embed_url is not None:
            self.power_bi_report_embed_url = power_bi_report_embed_url
        if error is not None:
            self.error = error

    @property
    def power_bi_report_access_token(self):
        """Gets the power_bi_report_access_token of this PowerBiReportChild.  # noqa: E501


        :return: The power_bi_report_access_token of this PowerBiReportChild.  # noqa: E501
        :rtype: str
        """
        return self._power_bi_report_access_token

    @power_bi_report_access_token.setter
    def power_bi_report_access_token(self, power_bi_report_access_token):
        """Sets the power_bi_report_access_token of this PowerBiReportChild.


        :param power_bi_report_access_token: The power_bi_report_access_token of this PowerBiReportChild.  # noqa: E501
        :type: str
        """

        self._power_bi_report_access_token = power_bi_report_access_token

    @property
    def power_bi_report_name(self):
        """Gets the power_bi_report_name of this PowerBiReportChild.  # noqa: E501


        :return: The power_bi_report_name of this PowerBiReportChild.  # noqa: E501
        :rtype: str
        """
        return self._power_bi_report_name

    @power_bi_report_name.setter
    def power_bi_report_name(self, power_bi_report_name):
        """Sets the power_bi_report_name of this PowerBiReportChild.


        :param power_bi_report_name: The power_bi_report_name of this PowerBiReportChild.  # noqa: E501
        :type: str
        """

        self._power_bi_report_name = power_bi_report_name

    @property
    def power_bi_report_url(self):
        """Gets the power_bi_report_url of this PowerBiReportChild.  # noqa: E501


        :return: The power_bi_report_url of this PowerBiReportChild.  # noqa: E501
        :rtype: str
        """
        return self._power_bi_report_url

    @power_bi_report_url.setter
    def power_bi_report_url(self, power_bi_report_url):
        """Sets the power_bi_report_url of this PowerBiReportChild.


        :param power_bi_report_url: The power_bi_report_url of this PowerBiReportChild.  # noqa: E501
        :type: str
        """

        self._power_bi_report_url = power_bi_report_url

    @property
    def power_bi_report_embed_url(self):
        """Gets the power_bi_report_embed_url of this PowerBiReportChild.  # noqa: E501


        :return: The power_bi_report_embed_url of this PowerBiReportChild.  # noqa: E501
        :rtype: str
        """
        return self._power_bi_report_embed_url

    @power_bi_report_embed_url.setter
    def power_bi_report_embed_url(self, power_bi_report_embed_url):
        """Sets the power_bi_report_embed_url of this PowerBiReportChild.


        :param power_bi_report_embed_url: The power_bi_report_embed_url of this PowerBiReportChild.  # noqa: E501
        :type: str
        """

        self._power_bi_report_embed_url = power_bi_report_embed_url

    @property
    def error(self):
        """Gets the error of this PowerBiReportChild.  # noqa: E501


        :return: The error of this PowerBiReportChild.  # noqa: E501
        :rtype: PowerBiError
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this PowerBiReportChild.


        :param error: The error of this PowerBiReportChild.  # noqa: E501
        :type: PowerBiError
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PowerBiReportChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PowerBiReportChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FrequencyDomainSettingChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'markers': 'list[MarkerChild]',
        'custom_markers': 'list[CustomMarkerChild]',
        'selected_bearing': 'str',
        'side_bands': 'int',
        'side_band_frequency': 'int'
    }

    attribute_map = {
        'markers': 'Markers',
        'custom_markers': 'CustomMarkers',
        'selected_bearing': 'SelectedBearing',
        'side_bands': 'SideBands',
        'side_band_frequency': 'SideBandFrequency'
    }

    def __init__(self, markers=None, custom_markers=None, selected_bearing=None, side_bands=None, side_band_frequency=None):  # noqa: E501
        """FrequencyDomainSettingChild - a model defined in Swagger"""  # noqa: E501
        self._markers = None
        self._custom_markers = None
        self._selected_bearing = None
        self._side_bands = None
        self._side_band_frequency = None
        self.discriminator = None
        if markers is not None:
            self.markers = markers
        if custom_markers is not None:
            self.custom_markers = custom_markers
        if selected_bearing is not None:
            self.selected_bearing = selected_bearing
        if side_bands is not None:
            self.side_bands = side_bands
        if side_band_frequency is not None:
            self.side_band_frequency = side_band_frequency

    @property
    def markers(self):
        """Gets the markers of this FrequencyDomainSettingChild.  # noqa: E501


        :return: The markers of this FrequencyDomainSettingChild.  # noqa: E501
        :rtype: list[MarkerChild]
        """
        return self._markers

    @markers.setter
    def markers(self, markers):
        """Sets the markers of this FrequencyDomainSettingChild.


        :param markers: The markers of this FrequencyDomainSettingChild.  # noqa: E501
        :type: list[MarkerChild]
        """

        self._markers = markers

    @property
    def custom_markers(self):
        """Gets the custom_markers of this FrequencyDomainSettingChild.  # noqa: E501


        :return: The custom_markers of this FrequencyDomainSettingChild.  # noqa: E501
        :rtype: list[CustomMarkerChild]
        """
        return self._custom_markers

    @custom_markers.setter
    def custom_markers(self, custom_markers):
        """Sets the custom_markers of this FrequencyDomainSettingChild.


        :param custom_markers: The custom_markers of this FrequencyDomainSettingChild.  # noqa: E501
        :type: list[CustomMarkerChild]
        """

        self._custom_markers = custom_markers

    @property
    def selected_bearing(self):
        """Gets the selected_bearing of this FrequencyDomainSettingChild.  # noqa: E501


        :return: The selected_bearing of this FrequencyDomainSettingChild.  # noqa: E501
        :rtype: str
        """
        return self._selected_bearing

    @selected_bearing.setter
    def selected_bearing(self, selected_bearing):
        """Sets the selected_bearing of this FrequencyDomainSettingChild.


        :param selected_bearing: The selected_bearing of this FrequencyDomainSettingChild.  # noqa: E501
        :type: str
        """

        self._selected_bearing = selected_bearing

    @property
    def side_bands(self):
        """Gets the side_bands of this FrequencyDomainSettingChild.  # noqa: E501


        :return: The side_bands of this FrequencyDomainSettingChild.  # noqa: E501
        :rtype: int
        """
        return self._side_bands

    @side_bands.setter
    def side_bands(self, side_bands):
        """Sets the side_bands of this FrequencyDomainSettingChild.


        :param side_bands: The side_bands of this FrequencyDomainSettingChild.  # noqa: E501
        :type: int
        """

        self._side_bands = side_bands

    @property
    def side_band_frequency(self):
        """Gets the side_band_frequency of this FrequencyDomainSettingChild.  # noqa: E501


        :return: The side_band_frequency of this FrequencyDomainSettingChild.  # noqa: E501
        :rtype: int
        """
        return self._side_band_frequency

    @side_band_frequency.setter
    def side_band_frequency(self, side_band_frequency):
        """Sets the side_band_frequency of this FrequencyDomainSettingChild.


        :param side_band_frequency: The side_band_frequency of this FrequencyDomainSettingChild.  # noqa: E501
        :type: int
        """

        self._side_band_frequency = side_band_frequency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FrequencyDomainSettingChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FrequencyDomainSettingChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class MonitoringPointsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_monitoring_point(self, **kwargs):  # noqa: E501
        """Creates a monitoringPoint  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_monitoring_point(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MonitoringPointCreateRequest body:
        :return: MonitoringPointResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_monitoring_point_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_monitoring_point_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_monitoring_point_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a monitoringPoint  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_monitoring_point_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MonitoringPointCreateRequest body:
        :return: MonitoringPointResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_monitoring_point" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/MonitoringPoints', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MonitoringPointResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_monitoring_point(self, monitoring_point_id, **kwargs):  # noqa: E501
        """Deletes a monitoringPoint  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_monitoring_point(monitoring_point_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitoring_point_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_monitoring_point_with_http_info(monitoring_point_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_monitoring_point_with_http_info(monitoring_point_id, **kwargs)  # noqa: E501
            return data

    def delete_monitoring_point_with_http_info(self, monitoring_point_id, **kwargs):  # noqa: E501
        """Deletes a monitoringPoint  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_monitoring_point_with_http_info(monitoring_point_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitoring_point_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['monitoring_point_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_monitoring_point" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'monitoring_point_id' is set
        if ('monitoring_point_id' not in params or
                params['monitoring_point_id'] is None):
            raise ValueError("Missing the required parameter `monitoring_point_id` when calling `delete_monitoring_point`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitoring_point_id' in params:
            path_params['monitoringPointId'] = params['monitoring_point_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/MonitoringPoints/{monitoringPointId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_monitoring_point(self, id, **kwargs):  # noqa: E501
        """Gets a Monitoring Point  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: MonitoringPointResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_monitoring_point_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_monitoring_point_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_monitoring_point_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a Monitoring Point  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: MonitoringPointResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_monitoring_point" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_monitoring_point`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/MonitoringPoints/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MonitoringPointResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_monitoring_point_assignments(self, monitoring_point_id, **kwargs):  # noqa: E501
        """Gets all of the node assignment history for a monitoring point including the current assignment.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point_assignments(monitoring_point_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitoring_point_id: The monitoringPointId to retrieve the node assignment history for. (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `IsPaused` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `NodeId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `NodeSerialNumber` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `EndDate` | DateTime? | | `StartDate` | DateTime |
        :return: PagedResultsModelMonitoringPointAssignmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_monitoring_point_assignments_with_http_info(monitoring_point_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_monitoring_point_assignments_with_http_info(monitoring_point_id, **kwargs)  # noqa: E501
            return data

    def get_monitoring_point_assignments_with_http_info(self, monitoring_point_id, **kwargs):  # noqa: E501
        """Gets all of the node assignment history for a monitoring point including the current assignment.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point_assignments_with_http_info(monitoring_point_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitoring_point_id: The monitoringPointId to retrieve the node assignment history for. (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `IsPaused` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `NodeId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `NodeSerialNumber` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `EndDate` | DateTime? | | `StartDate` | DateTime |
        :return: PagedResultsModelMonitoringPointAssignmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['monitoring_point_id', 'filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_monitoring_point_assignments" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'monitoring_point_id' is set
        if ('monitoring_point_id' not in params or
                params['monitoring_point_id'] is None):
            raise ValueError("Missing the required parameter `monitoring_point_id` when calling `get_monitoring_point_assignments`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitoring_point_id' in params:
            path_params['monitoringPointId'] = params['monitoring_point_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/MonitoringPoints/{monitoringPointId}/assignments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelMonitoringPointAssignmentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_monitoring_point_current_assignment(self, monitoring_point_id, **kwargs):  # noqa: E501
        """Gets the currently assigned node to a monitoring point  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point_current_assignment(monitoring_point_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitoring_point_id: The monitoringPointId used to retrieve the current assignment (required)
        :return: MonitoringPointAssignmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_monitoring_point_current_assignment_with_http_info(monitoring_point_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_monitoring_point_current_assignment_with_http_info(monitoring_point_id, **kwargs)  # noqa: E501
            return data

    def get_monitoring_point_current_assignment_with_http_info(self, monitoring_point_id, **kwargs):  # noqa: E501
        """Gets the currently assigned node to a monitoring point  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point_current_assignment_with_http_info(monitoring_point_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitoring_point_id: The monitoringPointId used to retrieve the current assignment (required)
        :return: MonitoringPointAssignmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['monitoring_point_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_monitoring_point_current_assignment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'monitoring_point_id' is set
        if ('monitoring_point_id' not in params or
                params['monitoring_point_id'] is None):
            raise ValueError("Missing the required parameter `monitoring_point_id` when calling `get_monitoring_point_current_assignment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitoring_point_id' in params:
            path_params['monitoringPointId'] = params['monitoring_point_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/MonitoringPoints/{monitoringPointId}/assignments/current', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MonitoringPointAssignmentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_monitoring_point_overview(self, **kwargs):  # noqa: E501
        """Gets an overview of monitoring point(s) which includes the node settings  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point_overview(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `HierarchyAbbreviation` | String | `eq, neq, like, in` | | `HierarchyName` | String | `eq, neq, like, in` | | `MonitoringPointType` | MonitoringPointTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` | | `NodeNickname` | String | `eq, neq, like, in` | | `NodeSerialNumber` | String | `eq, neq, like, in` | | `RunningSpeedMultiplier` | Double? | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `DecimationFactor` | NodeSettingValues | | `HierarchyAbbreviation` | String | | `HierarchyName` | String | | `MonitoringPointType` | MonitoringPointTypeCodes | | `Name` | String | | `NodeNickname` | String | | `NodeSerialNumber` | String | | `RunningSpeedMultiplier` | Double? | | `UpdateInterval` | NodeSettingValues |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `HierarchySearch`, `NodeNickname`, `NodeSerialNumber`.
        :return: PagedResultsModelMonitoringPointOverviewResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_monitoring_point_overview_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_monitoring_point_overview_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_monitoring_point_overview_with_http_info(self, **kwargs):  # noqa: E501
        """Gets an overview of monitoring point(s) which includes the node settings  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_point_overview_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `HierarchyAbbreviation` | String | `eq, neq, like, in` | | `HierarchyName` | String | `eq, neq, like, in` | | `MonitoringPointType` | MonitoringPointTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` | | `NodeNickname` | String | `eq, neq, like, in` | | `NodeSerialNumber` | String | `eq, neq, like, in` | | `RunningSpeedMultiplier` | Double? | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `DecimationFactor` | NodeSettingValues | | `HierarchyAbbreviation` | String | | `HierarchyName` | String | | `MonitoringPointType` | MonitoringPointTypeCodes | | `Name` | String | | `NodeNickname` | String | | `NodeSerialNumber` | String | | `RunningSpeedMultiplier` | Double? | | `UpdateInterval` | NodeSettingValues |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `HierarchySearch`, `NodeNickname`, `NodeSerialNumber`.
        :return: PagedResultsModelMonitoringPointOverviewResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_ids', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_monitoring_point_overview" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/MonitoringPoints/overview', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelMonitoringPointOverviewResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_monitoring_points(self, **kwargs):  # noqa: E501
        """Gets Monitoring Points  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_points(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Abbreviation` | String | `eq, neq, like, in` | | `Active` | Boolean | `eq, neq` | | `BearingId` | Guid | `eq, neq, in` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `IsPaused` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `MonitoringPointType` | MonitoringPointTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` | | `NodeId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `NodeSerialNumber` | String | `eq, neq, like, in` | | `ParentId` | Guid | `eq, neq, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Abbreviation` | String | | `CorporationName` | String | | `Created` | DateTime | | `LocationName` | String | | `Name` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Abbreviation`, `Name`.
        :return: PagedResultsModelMonitoringPointResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_monitoring_points_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_monitoring_points_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_monitoring_points_with_http_info(self, **kwargs):  # noqa: E501
        """Gets Monitoring Points  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_monitoring_points_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Abbreviation` | String | `eq, neq, like, in` | | `Active` | Boolean | `eq, neq` | | `BearingId` | Guid | `eq, neq, in` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `IsPaused` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `MonitoringPointType` | MonitoringPointTypeCodes | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` | | `NodeId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `NodeSerialNumber` | String | `eq, neq, like, in` | | `ParentId` | Guid | `eq, neq, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Abbreviation` | String | | `CorporationName` | String | | `Created` | DateTime | | `LocationName` | String | | `Name` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Abbreviation`, `Name`.
        :return: PagedResultsModelMonitoringPointResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_monitoring_points" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/MonitoringPoints', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelMonitoringPointResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_monitoring_point(self, monitoring_point_id, **kwargs):  # noqa: E501
        """Updates a monitoringPoint  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_monitoring_point(monitoring_point_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitoring_point_id: (required)
        :param MonitoringPointUpdateRequest body:
        :return: MonitoringPointResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_monitoring_point_with_http_info(monitoring_point_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_monitoring_point_with_http_info(monitoring_point_id, **kwargs)  # noqa: E501
            return data

    def update_monitoring_point_with_http_info(self, monitoring_point_id, **kwargs):  # noqa: E501
        """Updates a monitoringPoint  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_monitoring_point_with_http_info(monitoring_point_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str monitoring_point_id: (required)
        :param MonitoringPointUpdateRequest body:
        :return: MonitoringPointResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['monitoring_point_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_monitoring_point" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'monitoring_point_id' is set
        if ('monitoring_point_id' not in params or
                params['monitoring_point_id'] is None):
            raise ValueError("Missing the required parameter `monitoring_point_id` when calling `update_monitoring_point`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'monitoring_point_id' in params:
            path_params['monitoringPointId'] = params['monitoring_point_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/MonitoringPoints/{monitoringPointId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MonitoringPointResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IndicatorAlarmStateResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current_value': 'float',
        'last_update': 'datetime',
        'id': 'str',
        'alarm_severity': 'int'
    }

    attribute_map = {
        'current_value': 'CurrentValue',
        'last_update': 'LastUpdate',
        'id': 'Id',
        'alarm_severity': 'AlarmSeverity'
    }

    def __init__(self, current_value=None, last_update=None, id=None, alarm_severity=None):  # noqa: E501
        """IndicatorAlarmStateResponse - a model defined in Swagger"""  # noqa: E501
        self._current_value = None
        self._last_update = None
        self._id = None
        self._alarm_severity = None
        self.discriminator = None
        if current_value is not None:
            self.current_value = current_value
        if last_update is not None:
            self.last_update = last_update
        self.id = id
        if alarm_severity is not None:
            self.alarm_severity = alarm_severity

    @property
    def current_value(self):
        """Gets the current_value of this IndicatorAlarmStateResponse.  # noqa: E501

        Current Value of indicator  # noqa: E501

        :return: The current_value of this IndicatorAlarmStateResponse.  # noqa: E501
        :rtype: float
        """
        return self._current_value

    @current_value.setter
    def current_value(self, current_value):
        """Sets the current_value of this IndicatorAlarmStateResponse.

        Current Value of indicator  # noqa: E501

        :param current_value: The current_value of this IndicatorAlarmStateResponse.  # noqa: E501
        :type: float
        """

        self._current_value = current_value

    @property
    def last_update(self):
        """Gets the last_update of this IndicatorAlarmStateResponse.  # noqa: E501

        Last time it was updated  # noqa: E501

        :return: The last_update of this IndicatorAlarmStateResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update

    @last_update.setter
    def last_update(self, last_update):
        """Sets the last_update of this IndicatorAlarmStateResponse.

        Last time it was updated  # noqa: E501

        :param last_update: The last_update of this IndicatorAlarmStateResponse.  # noqa: E501
        :type: datetime
        """

        self._last_update = last_update

    @property
    def id(self):
        """Gets the id of this IndicatorAlarmStateResponse.  # noqa: E501

        Id of entity  # noqa: E501

        :return: The id of this IndicatorAlarmStateResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IndicatorAlarmStateResponse.

        Id of entity  # noqa: E501

        :param id: The id of this IndicatorAlarmStateResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def alarm_severity(self):
        """Gets the alarm_severity of this IndicatorAlarmStateResponse.  # noqa: E501

        Alarm severity  # noqa: E501

        :return: The alarm_severity of this IndicatorAlarmStateResponse.  # noqa: E501
        :rtype: int
        """
        return self._alarm_severity

    @alarm_severity.setter
    def alarm_severity(self, alarm_severity):
        """Sets the alarm_severity of this IndicatorAlarmStateResponse.

        Alarm severity  # noqa: E501

        :param alarm_severity: The alarm_severity of this IndicatorAlarmStateResponse.  # noqa: E501
        :type: int
        """

        self._alarm_severity = alarm_severity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IndicatorAlarmStateResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndicatorAlarmStateResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
